@@ -13,6 +13,20 @@ from flask_babelex import gettext as _
 INVENIO_CONFIG_TUGRAZ_SHIBBOLETH = True
 """Set True if SAML is configured"""
 
+INVENIO_CONFIG_TUGRAZ_SINGLE_IP = []
+"""Allows access to users whose IP address is listed.
+
+INVENIO_CONFIG_TUGRAZ_SINGLE_IP =
+    ["127.0.0.1", "127.0.0.2"]
+"""
+
+INVENIO_CONFIG_TUGRAZ_IP_RANGES = []
+"""Allows access to users whose range of IP address is listed.
+
+INVENIO_CONFIG_TUGRAZ_IP_RANGES =
+[["127.0.0.2", "127.0.0.99"], ["127.0.1.3", "127.0.1.5"]]
+"""
+
 # Invenio-App
 # ===========
 # See https://invenio-app.readthedocs.io/en/latest/configuration.html
@@ -56,7 +70,7 @@ APP_DEFAULT_SECURE_HEADERS = {
 # ===========
 # See https://invenio-mail.readthedocs.io/en/latest/configuration.html
 
-MAIL_SERVER = '129.27.11.182'
+MAIL_SERVER = 'localhost'
 """Domain ip where mail server is running."""
 
 SECURITY_EMAIL_SENDER = "info@invenio-test.tugraz.at"
@@ -66,8 +80,11 @@ SECURITY_EMAIL_SENDER = "info@invenio-test.tugraz.at"
 SECURITY_EMAIL_SUBJECT_REGISTER = _("Welcome to RDM!")
 """Email subject for account registration emails."""
 
-MAIL_SUPPRESS_SEND = False
-"""Enable email sending by default."""
+MAIL_SUPPRESS_SEND = True
+"""Enable email sending by default.
+
+Set this to False when sending actual emails.
+"""
 
 # CORS - Cross-origin resource sharing
 # ===========
@@ -98,7 +115,7 @@ when register.
 """
 
 SSO_SAML_IDPS = {}
-"""Configuration of IDPS. Actually values can be find in to invenio.cfg file"""
+"""Configuration of IDPS. Actual values can be find in to invenio.cfg file"""
 
 SSO_SAML_DEFAULT_BLUEPRINT_PREFIX = '/shibboleth'
 """Base URL for the extensions endpoint."""
@@ -137,4 +154,40 @@ able to register, or to navigate to /sigup page.
 """
 
 SECURITY_CONFIRMABLE = False
-"""Allow user to confirm their email address."""
+"""Allow user to confirm their email address.
+
+Instead user will get a welcome email.
+"""
+
+
+ACCOUNTS = True
+"""Tells if the templates should use the accounts module.
+
+If False, you won't be able to login via the web UI.
+
+Instead if you have a overriden template somewhere in your config.py:
+like this:
+SECURITY_LOGIN_USER_TEMPLATE = 'invenio_theme_tugraz/accounts/login.html'
+then you can remove this condition from header_login.htm:
+{%- if config.ACCOUNTS %}
+to render your overriden login.html
+"""
+
+# Accounts
+# ========
+# Actual values can be find in to invenio.cfg file
+#: Recaptcha public key (change to enable).
+RECAPTCHA_PUBLIC_KEY = None
+#: Recaptcha private key (change to enable).
+RECAPTCHA_PRIVATE_KEY = None
+
+# invenio-records-permissions
+# =======
+# See:
+# https://invenio-records-permissions.readthedocs.io/en/latest/configuration.html
+#
+# Uncomment these to enable overriden
+# RECORDS_PERMISSIONS_RECORD_POLICY = (
+#    'invenio_config_tugraz.permissions.TUGRAZPermissionPolicy'
+# )
+"""Access control configuration for records."""
